@@ -189,6 +189,8 @@ class Application(Gtk.Application):
         """
             Save window position and view
         """
+        if self._is_fs:
+            return
         if self.settings.get_value('save-state'):
             self.window.save_view_state()
             if self.player.current_track.id is None:
@@ -338,6 +340,8 @@ class Application(Gtk.Application):
             @param widget as Fullscreen
         """
         self._is_fs = False
+        if not self.window.is_visible():
+            self.prepare_to_exit()
 
     def _settings_dialog(self, action=None, param=None):
         """
@@ -389,6 +393,15 @@ class Application(Gtk.Application):
         """
         dialog.destroy()
 
+    def set_mini(self, action, param):
+        """
+            Set mini player on/off
+            @param dialog as Gtk.Dialog
+            @param response id as int
+        """
+        if self.window is not None:
+            self.window.set_mini()
+
     def _setup_app_menu(self):
         """
             Setup application menu
@@ -414,9 +427,14 @@ class Application(Gtk.Application):
 
         fsAction = Gio.SimpleAction.new('fullscreen', None)
         fsAction.connect('activate', self._fullscreen)
-        self.set_accels_for_action('app.fullscreen', ["F11", "<Control>m"])
+        self.set_accels_for_action('app.fullscreen', ["F11", "F7"])
         self.add_action(fsAction)
 
+        mini_action = Gio.SimpleAction.new('mini', None)
+        mini_action.connect('activate', self.set_mini)
+        self.add_action(mini_action)
+        self.set_accels_for_action("app.mini", ["<Control>m"])
+
         aboutAction = Gio.SimpleAction.new('about', None)
         aboutAction.connect('activate', self._about)
         self.set_accels_for_action('app.about', ["F2"])
