@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2015 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2016 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # Copyright (c) 2013 Vadim Rutkovsky <vrutkovs@redhat.com>
 # Copyright (c) 2013 Arnel A. Borja <kyoushuu@yahoo.com>
 # Copyright (c) 2013 Seif Lotfy <seif@lotfy.com>
@@ -40,6 +40,24 @@ class BaseArt(GObject.GObject):
 #######################
 # PRIVATE             #
 #######################
+    def _respect_ratio(self, path):
+        """
+            Check for aspect ratio based on size
+            @param path as str
+            @return respect aspect ratio as bool
+        """
+        cover = GdkPixbuf.Pixbuf.new_from_file(path)
+        cover_width = cover.get_width()
+        cover_height = cover.get_height()
+        if cover_width == cover_height:
+            return True
+        elif cover_width < cover_height:
+            cut = cover_height / 5
+            return cover_width < cover_height - cut
+        else:
+            cut = cover_width / 5
+            return cover_height < cover_width - cut
+
     def _create_cache(self):
         """
             Create cache dir
