@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2015 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2016 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -179,12 +179,13 @@ class CollectionScanner(GObject.GObject, ScannerTagReader):
                         if mtime != mtimes[filepath]:
                             debug("Adding file: %s" % filepath)
                             infos = self.get_infos(filepath)
+                            track_id = Lp().tracks.get_id_by_path(filepath)
+                            self._del_from_db(track_id)
                             if infos is not None:
                                 self._add2db(filepath, mtime, infos)
                             else:
                                 print("Can't get infos for ", filepath)
-                        else:
-                            orig_tracks.remove(filepath)
+                        orig_tracks.remove(filepath)
 
                 except Exception as e:
                     print(ascii(filepath))
