@@ -67,8 +67,13 @@ class Shuffle:
     NONE = 0             # No shuffle
     TRACKS = 1           # Shuffle by tracks on genre
     ALBUMS = 2           # Shuffle by albums on genre
-    TRACKS_ARTIST = 3    # Shuffle by tracks on artist
-    ALBUMS_ARTIST = 4    # Shuffle by albums on artist
+
+
+class WindowSize:
+    SMALL = 400
+    MEDIUM = 500
+    BIG = 700
+    MONSTER = 800
 
 
 # Order is important
