@@ -19,7 +19,6 @@ from lollypop.player_externals import ExternalsPlayer
 from lollypop.player_userplaylist import UserPlaylistPlayer
 from lollypop.objects import Track
 from lollypop.define import Lp, Type
-from lollypop.define import Shuffle
 
 
 class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
@@ -46,16 +45,16 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
             Play previous track
         """
         if self.prev_track.id is not None:
-            self.load(self.prev_track, False)
+            self.load(self.prev_track)
 
     def next(self):
         """
             Play next track
         """
         if self.next_track.id is not None:
-            self.load(self.next_track, False)
+            self.load(self.next_track)
 
-    def load(self, track, notify=True):
+    def load(self, track):
         """
             Stop current track, load track id and play it
             @param track as Track
@@ -67,7 +66,7 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
                 Lp().window.pulse(True)
             RadioPlayer.load(self, track)
         else:
-            BinPlayer.load(self, track, notify)
+            BinPlayer.load(self, track)
 
     def play_album(self, album):
         """
@@ -101,17 +100,15 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
         # We are in all artists
         if (genre_ids and genre_ids[0] == Type.ALL) or\
            (artist_ids and artist_ids[0] == Type.ALL):
-            self._albums = Lp().albums.get_compilations()
-            self._albums += Lp().albums.get_ids()
+            if artist_ids and artist_ids[0] != Type.ALL:
+                self._albums += Lp().albums.get_ids(artist_ids, None)
+            else:
+                if Lp().settings.get_value('show-compilations'):
+                    self._albums = Lp().albums.get_compilations()
+                self._albums += Lp().albums.get_ids()
         # We are in populars view, add popular albums
         elif genre_ids and genre_ids[0] == Type.POPULARS:
-            if self._shuffle in [Shuffle.TRACKS_ARTIST, Shuffle.ALBUMS_ARTIST]:
-                self._albums = []
-                for album_id in Lp().albums.get_populars():
-                    if Lp().albums.get_artist_id(album_id) in artist_ids:
-                        self._albums.append(album_id)
-            else:
-                self._albums = Lp().albums.get_populars()
+            self._albums = Lp().albums.get_populars()
         # We are in recents view, add recent albums
         elif genre_ids and genre_ids[0] == Type.RECENTS:
             self._albums = Lp().albums.get_recents()
@@ -121,13 +118,8 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
         # We are in compilation view without genre
         elif genre_ids and genre_ids[0] == Type.COMPILATIONS:
             self._albums = Lp().albums.get_compilations()
-        # Random tracks/albums for artist
-        elif self._shuffle in [Shuffle.TRACKS_ARTIST, Shuffle.ALBUMS_ARTIST]:
-            self._albums = Lp().albums.get_ids([album.artist_id], genre_ids)
-        # Add all albums for genre
+        # Add albums for artists/genres
         else:
-            if not artist_ids:
-                self._albums = Lp().albums.get_compilations(genre_ids)
             self._albums += Lp().albums.get_ids(artist_ids, genre_ids)
 
         album.set_genre(genre_ids)
@@ -182,8 +174,6 @@ class Player(BinPlayer, QueuePlayer, UserPlaylistPlayer, RadioPlayer,
         ShufflePlayer.set_party(self, party)
         self.set_next()
         self.set_prev()
-        if self.is_playing():
-            self.emit('next-changed')
         self.update_crossfading()
 
     def set_prev(self):
