@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2015 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2016 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -140,6 +140,9 @@ class Playlists(GObject.GObject):
             sql.execute("DELETE FROM playlists\
                         WHERE name=?",
                         (name,))
+            sql.execute("DELETE FROM tracks\
+                        WHERE playlist_id=?",
+                        (playlist_id,))
             sql.commit()
             GLib.idle_add(self.emit, 'playlists-changed', playlist_id)
 
