@@ -90,12 +90,9 @@ class InfosPopover(Gtk.Popover):
         """
             Set widget size
         """
-        size_setting = Lp().settings.get_value('window-size')
-        if isinstance(size_setting[1], int):
-            self.set_size_request(size_setting[0]*0.6,
-                                  size_setting[1]*0.7)
-        else:
-            self.set_size_request(700, 600)
+        size = Lp().window.get_size()
+        self.set_size_request(size[0]*0.6,
+                              size[1]*0.7)
         Gtk.Popover.do_show(self)
 
     def do_get_preferred_width(self):
