@@ -12,7 +12,7 @@
 
 from gi.repository import Gtk
 
-from lollypop.define import Lp, ArtSize, Shuffle
+from lollypop.define import Lp, ArtSize
 
 
 class NextPopover(Gtk.Popover):
@@ -25,6 +25,7 @@ class NextPopover(Gtk.Popover):
             Init popover
         """
         Gtk.Popover.__init__(self)
+        self._should_be_shown = True
         self.set_position(Gtk.PositionType.BOTTOM)
         self.connect('map', self._on_map)
         self.connect('unmap', self._on_unmap)
@@ -44,9 +45,6 @@ class NextPopover(Gtk.Popover):
         """
             Update widget with current track
         """
-        if Lp().player.is_party() or\
-                Lp().settings.get_enum('shuffle') == Shuffle.TRACKS:
-            self._skip_btn.show()
         self._artist_label.set_text(Lp().player.next_track.artist)
         self._title_label.set_text(Lp().player.next_track.title)
         art = Lp().art.get_album_artwork(
@@ -60,6 +58,12 @@ class NextPopover(Gtk.Popover):
         else:
             self._cover.hide()
 
+    def should_be_shown(self):
+        """
+            Return True if widget should be shown, not already closed by user
+        """
+        return self._should_be_shown
+
 #######################
 # PRIVATE             #
 #######################
@@ -68,6 +72,7 @@ class NextPopover(Gtk.Popover):
             Connect signal
             @param widget as Gtk.Widget
         """
+        self._should_be_shown = True
         self._signal_id = Lp().player.connect('queue-changed', self.update)
 
     def _on_unmap(self, widget):
@@ -78,6 +83,31 @@ class NextPopover(Gtk.Popover):
         if self._signal_id is not None:
             Lp().player.disconnect(self._signal_id)
 
+    def _on_enter_notify(self, widget, event):
+        """
+            Change opacity
+            @param widget as Gtk.Widget
+            @param event as Gdk.Event
+        """
+        widget.set_opacity(0.8)
+
+    def _on_leave_notify(self, widget, event):
+        """
+            Change opacity
+            @param widget as Gtk.Widget
+            @param event as Gdk.Event
+        """
+        widget.set_opacity(0.2)
+
+    def _on_button_release(self, widget, event):
+        """
+            Hide popover
+            @param widget as Gtk.Widget
+            @param event as Gdk.Event
+        """
+        self._should_be_shown = False
+        self.hide()
+
     def _on_skip_btn_clicked(self, btn):
         """
             Skip next track
