@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2015 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2016 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -10,7 +10,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib, Gio
+from gi.repository import Gtk, GLib, Gio, GdkPixbuf, Gdk, Pango
 
 from threading import Thread
 from gettext import gettext as _
@@ -39,6 +39,7 @@ class TuneinPopover(Gtk.Popover):
             self._radios_manager = Radios()
         self._current_url = None
         self._previous_urls = []
+        self._covers_to_download = []
 
         self._stack = Gtk.Stack()
         self._stack.set_property('expand', True)
@@ -61,14 +62,15 @@ class TuneinPopover(Gtk.Popover):
         self._view.set_property('expand', True)
         self._view.show()
 
+        self._spinner = builder.get_object('spinner')
+
         builder.get_object('viewport').add(self._view)
         builder.get_object('viewport').set_property('margin', 10)
 
         self._scrolled = builder.get_object('scrolled')
-        self._stack.add_named(builder.get_object('spinner'), 'spinner')
+        self._stack.add_named(self._spinner, 'spinner')
         self._stack.add_named(builder.get_object('notfound'), 'notfound')
         self._stack.add_named(self._scrolled, 'scrolled')
-        self._stack.set_visible_child_name('spinner')
         self.add(widget)
         size_setting = Lp().settings.get_value('window-size')
         if isinstance(size_setting[1], int):
@@ -81,7 +83,9 @@ class TuneinPopover(Gtk.Popover):
             Populate views
             @param url as string
         """
-        if not self._view.get_children():
+        if not self._view.get_children() or\
+           self._stack.get_visible_child_name() == "notfound":
+            self._stack.set_visible_child_name('spinner')
             self._current_url = url
             self._clear()
             self._back_btn.set_sensitive(False)
@@ -124,18 +128,26 @@ class TuneinPopover(Gtk.Popover):
             @param items as [TuneItem]
             @thread safe
         """
-        for item in items:
-            GLib.idle_add(self._add_item, item)
+        GLib.idle_add(self._add_item, items)
 
-    def _add_item(self, item):
+    def _add_item(self, items):
         """
             Add item
-            @param item as TuneItem
+            @param items as [TuneItem]
         """
+        if not items:
+            t = Thread(target=self._download_images)
+            t.daemon = True
+            t.start()
+            return
+        item = items.pop(0)
         child = Gtk.Grid()
+        child.set_column_spacing(5)
         child.set_property('halign', Gtk.Align.START)
         child.show()
         link = Gtk.LinkButton.new_with_label(item.URL, item.TEXT)
+        # Hack
+        link.get_children()[0].set_ellipsize(Pango.EllipsizeMode.END)
         link.connect('activate-link', self._on_activate_link, item)
         link.show()
         if item.TYPE == "audio":
@@ -144,9 +156,16 @@ class TuneinPopover(Gtk.Popover):
                                                    Gtk.IconSize.MENU)
             button.connect('clicked', self._on_button_clicked, item)
             button.set_relief(Gtk.ReliefStyle.NONE)
+            button.set_property('valign', Gtk.Align.CENTER)
             button.set_tooltip_text(_("Add"))
             button.show()
             child.add(button)
+            image = Gtk.Image.new()
+            image.set_property('width-request', ArtSize.MEDIUM)
+            image.set_property('height-request', ArtSize.MEDIUM)
+            image.show()
+            child.add(image)
+            self._covers_to_download.append((item, image))
         else:
             link.set_tooltip_text('')
         child.add(link)
@@ -156,10 +175,50 @@ class TuneinPopover(Gtk.Popover):
         # Remove spinner if exist
         if self._stack.get_visible_child_name() == 'spinner':
             self._stack.set_visible_child_name('scrolled')
+            self._spinner.stop()
             self._label.set_text(_("Browse themes and add a new radio"))
             if self._current_url is not None:
                 self._back_btn.set_sensitive(True)
             self._home_btn.set_sensitive(True)
+        GLib.idle_add(self._add_items, items)
+
+    def _download_images(self):
+        """
+            Download and set image for TuneItem
+            @thread safe
+        """
+        while self._covers_to_download:
+            (item, image) = self._covers_to_download.pop(0)
+            try:
+                f = Gio.File.new_for_uri(item.LOGO)
+                (status, data, tag) = f.load_contents()
+                if status:
+                    stream = Gio.MemoryInputStream.new_from_data(data, None)
+                    if stream is not None:
+                        GLib.idle_add(self._set_image, image, stream)
+            except Exception as e:
+                GLib.idle_add(image.set_from_icon_name,
+                              "image-missing",
+                              Gtk.IconSize.LARGE_TOOLBAR)
+                print("TuneinPopover::_download_images: %s" % e)
+
+    def _set_image(self, image, stream):
+        """
+            Set image with stream
+            @param image as Gtk.Image
+            @param stream as Gio.MemoryInputStream
+        """
+        pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(stream,
+                                                           ArtSize.MEDIUM,
+                                                           ArtSize.MEDIUM,
+                                                           True,
+                                                           None)
+        surface = Gdk.cairo_surface_create_from_pixbuf(pixbuf,
+                                                       0,
+                                                       None)
+        del pixbuf
+        image.set_from_surface(surface)
+        del surface
 
     def _clear(self):
         """
@@ -204,6 +263,7 @@ class TuneinPopover(Gtk.Popover):
         if self._previous_urls:
             url = self._previous_urls.pop()
         self._stack.set_visible_child_name('spinner')
+        self._spinner.start()
         self._clear()
         self.populate(url)
 
@@ -215,6 +275,7 @@ class TuneinPopover(Gtk.Popover):
         self._current_url = None
         self._previous_urls = []
         self._stack.set_visible_child_name('spinner')
+        self._spinner.start()
         self._clear()
         self.populate()
 
@@ -226,6 +287,7 @@ class TuneinPopover(Gtk.Popover):
         """
         if item.TYPE == "link":
             self._stack.set_visible_child_name('spinner')
+            self._spinner.start()
             self._clear()
             self._scrolled.get_vadjustment().set_value(0.0)
             if self._current_url is not None:
