@@ -86,6 +86,7 @@ class AlbumsView(View):
         self._viewport.set_property('valign', Gtk.Align.START)
         self._viewport.set_property('margin', 5)
         self._scrolled.set_property('expand', True)
+        self._scrolled.set_property('height-request', 10)
         self._scrolled.get_vadjustment().connect('value-changed',
                                                  self._on_value_changed)
         self._context = ViewContainer(500)
@@ -96,12 +97,7 @@ class AlbumsView(View):
         self._paned = Gtk.Paned.new(Gtk.Orientation.VERTICAL)
         self._paned.pack1(self._scrolled, True, False)
         self._paned.pack2(self._context, False, False)
-        height = Lp().settings.get_value('paned-context-height').get_int32()
-        # We set a stupid max value, safe as self._context is shrinked
-        if height == -1:
-            height = Lp().window.get_allocated_height()
-        self._paned.set_position(height)
-        self._paned.connect('notify::position', self._on_position_notify)
+        self._paned.set_position(Lp().window.get_allocated_height())
         self._paned.show()
         self.add(self._paned)
 
@@ -110,16 +106,18 @@ class AlbumsView(View):
             Populate albums
             @param is compilation as bool
         """
-        # Add first album to get album size,
-        # used to precalculate next albums size
-        if albums:
-            widget = AlbumSimpleWidget(albums.pop(0))
-            widget.init_widget()
-            widget.show_all()
-            self._albumbox.insert(widget, -1)
-            # Keep album requisition
-            self._requisition = widget.get_preferred_size()[1]
-            self._add_albums(albums)
+        self._add_albums(albums)
+
+    def show_context(self, show):
+        """
+            Hide context widget
+            @param show as bool
+        """
+        if show:
+            if self._context_widget is not None:
+                self._context.show()
+        elif self._context_widget is not None:
+            self._context.hide()
 
 #######################
 # PRIVATE             #
@@ -145,7 +143,6 @@ class AlbumsView(View):
         size_group = Gtk.SizeGroup(mode=Gtk.SizeGroupMode.HORIZONTAL)
         self._context_widget = AlbumContextWidget(album_id,
                                                   self._genre_id,
-                                                  False,
                                                   size_group)
         self._context_widget.populate()
         self._context_widget.show()
@@ -162,9 +159,7 @@ class AlbumsView(View):
             @param [album ids as int]
         """
         if albums and not self._stop:
-            widget = AlbumSimpleWidget(albums.pop(0),
-                                       self._requisition.width,
-                                       self._requisition.height)
+            widget = AlbumSimpleWidget(albums.pop(0))
             self._albumbox.insert(widget, -1)
             widget.show_all()
             self._lazy_queue.append(widget)
@@ -231,16 +226,6 @@ class AlbumsView(View):
             return
         self._timeout_id = GLib.timeout_add(250, self._lazy_or_not)
 
-    def _on_position_notify(self, paned, param):
-        """
-            Save paned position
-            @param paned as Gtk.Paned
-            @param param as Gtk.Param
-        """
-        Lp().settings.set_value('paned-context-height',
-                                GLib.Variant('i', paned.get_position()))
-        return False
-
     def _on_album_activated(self, flowbox, child):
         """
             Show Context view for activated album
