@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2015 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2016 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -19,7 +19,7 @@ from lollypop.widgets_radio import RadioWidget
 from lollypop.radios import Radios
 from lollypop.pop_radio import RadioPopover
 from lollypop.pop_tunein import TuneinPopover
-from lollypop.define import Lp
+from lollypop.define import Lp, Type
 from lollypop.objects import Track
 
 
@@ -79,6 +79,10 @@ class RadiosView(View):
             Populate view with tracks from playlist
             Thread safe
         """
+        Lp().player.set_radios(self._radios_manager.get())
+        if Lp().player.current_track.id == Type.RADIOS:
+            Lp().player.set_next()  # We force next update
+            Lp().player.set_prev()  # We force prev update
         t = Thread(target=self._populate)
         t.daemon = True
         t.start()
@@ -177,6 +181,18 @@ class RadiosView(View):
             if not self._radiobox.get_children():
                 self._show_stack([])
 
+        # Update player state based on current view
+        radios = []
+        for child in self._radiobox.get_children():
+            widget = child.get_child()
+            name = widget.get_name()
+            url = manager.get_url(name)
+            radios.append((name, url))
+        Lp().player.set_radios(radios)
+        if Lp().player.current_track.id == Type.RADIOS:
+            Lp().player.set_next()  # We force next update
+            Lp().player.set_prev()  # We force prev update
+
     def _on_logo_changed(self, player, name):
         """
             Update radio logo
