@@ -15,7 +15,7 @@ from gi.repository import Gtk, GLib, GObject, Gdk, Pango
 from cgi import escape
 from gettext import gettext as _
 
-from lollypop.define import Lp, Type, ArtSize, NextContext
+from lollypop.define import Lp, Type, ArtSize, NextContext, WindowSize
 from lollypop.widgets_track import TracksWidget
 from lollypop.objects import Track
 from lollypop.widgets_rating import RatingWidget
@@ -64,6 +64,12 @@ class AlbumWidget:
         self._cover.set_from_surface(surface)
         del surface
 
+    def responsive_design(self):
+        """
+            Update the view based on current size
+        """
+        pass
+
     def update_state(self):
         """
             Update widget state
@@ -154,12 +160,10 @@ class AlbumSimpleWidget(Gtk.Frame, AlbumWidget):
         Album widget showing cover, artist and title
     """
 
-    def __init__(self, album_id, width=0, height=0):
+    def __init__(self, album_id):
         """
             Init simple album widget
             @param album id as int
-            @param width request as int
-            @param height request as int
         """
         # We do not use Gtk.Builder for speed reasons
         Gtk.Frame.__init__(self)
@@ -169,9 +173,6 @@ class AlbumSimpleWidget(Gtk.Frame, AlbumWidget):
         self._album = None
         self._cover = None
         self._eventbox = None
-        self._width = width
-        if width != 0 and height != 0:
-            self.set_size_request(width, height)
 
     def init_widget(self):
         """
@@ -182,6 +183,7 @@ class AlbumSimpleWidget(Gtk.Frame, AlbumWidget):
         self._widget = Gtk.EventBox()
         self._widget.connect('enter-notify-event', self._on_enter_notify)
         self._widget.connect('leave-notify-event', self._on_leave_notify)
+        self._widget.connect('realize', self._on_eventbox_realize)
         self._widget.set_property('has-tooltip', True)
         grid = Gtk.Grid()
         grid.set_orientation(Gtk.Orientation.VERTICAL)
@@ -228,11 +230,11 @@ class AlbumSimpleWidget(Gtk.Frame, AlbumWidget):
             Return preferred width
             @return (int, int)
         """
-        if self._width != 0:
-            return (self._width, self._width)
-        else:
+        if self._cover is not None:
             widths = self._cover.get_preferred_width()
             return (widths[0] + 8, widths[1] + 8)
+        else:
+            return (0, 0)
 
     def update_cursor(self):
         """
@@ -274,28 +276,29 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
         'finished': (GObject.SignalFlags.RUN_FIRST, None, ())
     }
 
-    def __init__(self, album_id, genre_ids, artist_ids, popover, size_group):
+    def __init__(self, album_id, genre_ids, artist_ids, size_group):
         """
             Init detailed album widget
             @param album id as int
             @param genre ids as [int]
             @param artist ids as [int]
-            @param popover as bool
             @param size group as Gtk.SizeGroup
         """
         Gtk.Bin.__init__(self)
         AlbumWidget.__init__(self, album_id, genre_ids)
         self._artist_ids = artist_ids
-        self._pop_allowed = not popover or Gtk.get_minor_version() > 16
         self.set_property('height-request', ArtSize.BIG)
         builder = Gtk.Builder()
         builder.add_from_resource('/org/gnome/Lollypop/%s.ui' %
                                   type(self).__name__)
-        self._color = builder.get_object('color')
+        builder.connect_signals(self)
+
         rating = RatingWidget(self._album)
         rating.show()
-        builder.get_object('coverbox').add(rating)
-        builder.connect_signals(self)
+        self._coverbox = builder.get_object('coverbox')
+        self._coverbox.add(rating)
+        if Lp().window.get_view_width() < WindowSize.MEDIUM:
+            self._coverbox.hide()
 
         self._artist_label = builder.get_object('artist')
         if len(artist_ids) > 1:
@@ -313,13 +316,15 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
                 label.set_text(_("%s h") % hours)
         else:
             label.set_text(_("%s m") % mins)
-
-        grid = builder.get_object('tracks')
+        self._box = Gtk.FlowBox()
+        self._box.set_selection_mode(Gtk.SelectionMode.NONE)
+        self._box.set_hexpand(True)
+        self._box.show()
+        builder.get_object('albuminfos').add(self._box)
         self._discs = self._album.discs
         self._tracks_left = {}
         self._tracks_right = {}
         show_label = len(self._discs) > 1
-        i = 0
         for disc in self._discs:
             index = disc.number
             if show_label:
@@ -327,15 +332,16 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
                 label.set_text(_("Disc %s") % index)
                 label.set_property('halign', Gtk.Align.START)
                 label.get_style_context().add_class('dim-label')
-                if i:
-                    label.set_property('margin-top', 30)
                 label.show()
-                grid.attach(label, 0, i, 2, 1)
-                i += 1
-            self._tracks_left[index] = TracksWidget(self._pop_allowed, True)
-            self._tracks_right[index] = TracksWidget(self._pop_allowed, True)
-            grid.attach(self._tracks_left[index], 0, i, 1, 1)
-            grid.attach(self._tracks_right[index], 1, i, 1, 1)
+                self._box.insert(label, -1)
+                sep = Gtk.Separator()
+                sep.set_opacity(0.0)
+                sep.show()
+                self._box.insert(sep, -1)
+            self._tracks_left[index] = TracksWidget(True)
+            self._tracks_right[index] = TracksWidget(True)
+            self._box.insert(self._tracks_left[index], -1)
+            self._box.insert(self._tracks_right[index], -1)
             size_group.add_widget(self._tracks_left[index])
             size_group.add_widget(self._tracks_right[index])
 
@@ -349,9 +355,10 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
 
             self._tracks_left[index].show()
             self._tracks_right[index].show()
-            i += 1
 
         self._cover = builder.get_object('cover')
+        self._color = builder.get_object('color')
+        self.responsive_design()
         self.set_cover()
         self.update_state()
 
@@ -363,12 +370,25 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
 
         self.add(builder.get_object('widget'))
 
-        # TODO: Remove this test later
-        if self._pop_allowed:
-            self._menu = builder.get_object('menu')
-            self._menu.connect('clicked',
-                               self._pop_menu)
-            self._menu.show()
+        self._menu = builder.get_object('menu')
+        self._menu.connect('clicked', self._pop_menu)
+        self._menu.show()
+
+    def responsive_design(self):
+        """
+            Update the view based on current size
+        """
+        width = Lp().window.get_view_width()
+        if width < WindowSize.MONSTER:
+            self._box.set_min_children_per_line(1)
+            self._box.set_max_children_per_line(1)
+        else:
+            self._box.set_min_children_per_line(2)
+            self._box.set_max_children_per_line(2)
+        if width < WindowSize.MEDIUM:
+            self._coverbox.hide()
+        else:
+            self._coverbox.show()
 
     def update_playing_indicator(self):
         """
@@ -504,14 +524,9 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
         else:
             Lp().player.context.next = NextContext.NONE
             if not Lp().player.is_party():
-                if len(self._artist_ids) > 1:
-                    Lp().player.set_albums(track_id,
-                                           self._artist_ids,
-                                           self._album.genre_ids)
-                else:
-                    Lp().player.set_albums(track_id,
-                                           [],
-                                           self._album.genre_ids)
+                Lp().player.set_albums(track_id,
+                                       self._artist_ids,
+                                       self._album.genre_ids)
             Lp().player.load(Track(track_id))
             if self._button_state & Gdk.ModifierType.CONTROL_MASK:
                 Lp().player.context.next = NextContext.STOP_TRACK
@@ -533,7 +548,7 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
         """
         if event.button == 1:
             Lp().player.play_album(self._album)
-        elif self._pop_allowed:
+        else:
             popover = CoversPopover(self._album.artist_id, self._album.id)
             popover.set_relative_to(widget)
             popover.populate()
