@@ -22,15 +22,14 @@ class AlbumContextWidget(AlbumDetailedWidget):
         Widget with cover and tracks
     """
 
-    def __init__(self, album_id, genre_id, popover, size_group):
+    def __init__(self, album_id, genre_id, size_group):
         """
             Init detailed album widget
             @param album id as int
             @param genre id as int
             @param size group as Gtk.SizeGroup
         """
-        AlbumDetailedWidget.__init__(self, album_id, genre_id,
-                                     [], popover, size_group)
+        AlbumDetailedWidget.__init__(self, album_id, genre_id, [], size_group)
         self._artist_label.set_text(self._album.artist_name)
         self._artist_label.show()
 
@@ -75,7 +74,6 @@ class AlbumPopoverWidget(Gtk.Popover):
         size_group = Gtk.SizeGroup(mode=Gtk.SizeGroupMode.HORIZONTAL)
         self._widget = AlbumContextWidget(album_id,
                                           genre_id,
-                                          True,
                                           size_group)
         self._widget.populate()
         self._widget.show()
@@ -91,11 +89,7 @@ class AlbumPopoverWidget(Gtk.Popover):
         """
             Set maximum width
         """
-        size_setting = Lp().settings.get_value('window-size')
-        if isinstance(size_setting[0], int):
-            width = size_setting[0] * 0.6
-        else:
-            width = 500
+        width = min(900, Lp().window.get_size()[0] - 10)
         return (width, width)
 
 #######################
