@@ -53,25 +53,22 @@ class Row(Gtk.ListBoxRow):
         self._num_label.set_ellipsize(Pango.EllipsizeMode.END)
         self._num_label.set_width_chars(4)
         self._num_label.get_style_context().add_class('dim-label')
+        button = Gtk.Button.new_from_icon_name('open-menu-symbolic',
+                                               Gtk.IconSize.MENU)
+        button.set_relief(Gtk.ReliefStyle.NONE)
+        button.get_style_context().add_class('menu-button')
+        button.get_style_context().add_class('track-menu-button')
+        button.get_image().set_opacity(0.2)
+        button.show()
+        self._row_widget.connect('button-press-event', self._on_button_press)
+        button.connect('clicked', self._on_button_clicked)
         self._grid.add(self._num_label)
         self._grid.add(self._title_label)
         self._grid.add(self._duration_label)
+        self._grid.add(button)
         self.add(self._row_widget)
         self.get_style_context().add_class('trackrow')
 
-    def show_cover(self, show):
-        """
-            Show cover
-            @param show as bool
-        """
-        pass
-
-    def show_menu(self, show):
-        """
-            Show menu
-        """
-        pass
-
     def show_indicator(self, playing, loved):
         """
             Show indicator
@@ -155,6 +152,54 @@ class Row(Gtk.ListBoxRow):
 #######################
 # PRIVATE             #
 #######################
+    def _on_button_press(self, widget, event):
+        """
+            Popup menu for track relative to track row
+            @param widget as Gtk.Widget
+            @param event as Gdk.Event
+        """
+        if event.button != 1:
+            window = widget.get_window()
+            if window == event.window:
+                self._popup_menu(widget, event.x, event.y)
+            # Happens when pressing button over menu btn
+            else:
+                self._popup_menu(self._menu_btn)
+            return True
+
+    def _on_button_clicked(self, widget):
+        """
+            Popup menu for track relative to button
+            @param widget as Gtk.Button
+        """
+        self._popup_menu(widget)
+
+    def _popup_menu(self, widget, xcoordinate=None, ycoordinate=None):
+        """
+            Popup menu for track
+            @param widget as Gtk.Button
+            @param xcoordinate as int (or None)
+            @param ycoordinate as int (or None)
+        """
+        popover = TrackMenuPopover(self._object_id, TrackMenu(self._object_id))
+        popover.set_relative_to(widget)
+        if xcoordinate is not None and ycoordinate is not None:
+            rect = widget.get_allocation()
+            rect.x = xcoordinate
+            rect.y = ycoordinate
+            rect.width = rect.height = 1
+            popover.set_pointing_to(rect)
+        popover.connect('closed', self._on_closed)
+        self.get_style_context().add_class('track-menu-selected')
+        popover.show()
+
+    def _on_closed(self, widget):
+        """
+            Remove selected style
+            @param widget as Gtk.Popover
+        """
+        self.get_style_context().remove_class('track-menu-selected')
+
     def _on_title_query_tooltip(self, widget, x, y, keyboard, tooltip):
         """
             Show tooltip if needed
@@ -260,33 +305,15 @@ class TrackRow(Row):
         A track row
     """
 
-    def __init__(self, show_menu, show_loved):
+    def __init__(self, show_loved):
         """
             Init row widget and show it
-            @parma show menu as bool
             @param show loved as bool
         """
         Row.__init__(self, show_loved)
         self._grid.insert_column(0)
         self._grid.attach(self._indicator, 0, 0, 1, 1)
         self.show_all()
-        button = Gtk.Button.new_from_icon_name('open-menu-symbolic',
-                                               Gtk.IconSize.MENU)
-        button.set_relief(Gtk.ReliefStyle.NONE)
-        button.get_style_context().add_class('menu-button')
-        button.get_style_context().add_class('track-menu-button')
-        button.get_image().set_opacity(0.2)
-        self._grid.add(button)
-        # TODO: Remove this test later
-        if show_menu:
-            button.show()
-            self._show_menu = True
-            self._row_widget.connect('button-press-event',
-                                     self._on_button_press)
-            button.connect('clicked', self._on_button_clicked)
-        else:
-            self._show_menu = False
-            button.hide()
 
     def set_object_id(self, object_id):
         """
@@ -299,53 +326,6 @@ class TrackRow(Row):
 #######################
 # PRIVATE             #
 #######################
-    def _on_button_press(self, widget, event):
-        """
-            Popup menu for track relative to track row
-            @param widget as Gtk.Widget
-            @param event as Gdk.Event
-        """
-        if event.button != 1:
-            window = widget.get_window()
-            if window == event.window:
-                self._popup_menu(widget, event.x, event.y)
-            # Happens when pressing button over menu btn
-            else:
-                self._popup_menu(self._menu_btn)
-            return True
-
-    def _on_button_clicked(self, widget):
-        """
-            Popup menu for track relative to button
-            @param widget as Gtk.Button
-        """
-        self._popup_menu(widget)
-
-    def _popup_menu(self, widget, xcoordinate=None, ycoordinate=None):
-        """
-            Popup menu for track
-            @param widget as Gtk.Button
-            @param xcoordinate as int (or None)
-            @param ycoordinate as int (or None)
-        """
-        popover = TrackMenuPopover(self._object_id, TrackMenu(self._object_id))
-        popover.set_relative_to(widget)
-        if xcoordinate is not None and ycoordinate is not None:
-            rect = widget.get_allocation()
-            rect.x = xcoordinate
-            rect.y = ycoordinate
-            rect.width = rect.height = 1
-            popover.set_pointing_to(rect)
-        popover.connect('closed', self._on_closed)
-        self.get_style_context().add_class('track-menu-selected')
-        popover.show()
-
-    def _on_closed(self, widget):
-        """
-            Remove selected style
-            @param widget as Gtk.Popover
-        """
-        self.get_style_context().remove_class('track-menu-selected')
 
 
 class TracksWidget(Gtk.ListBox):
@@ -357,10 +337,10 @@ class TracksWidget(Gtk.ListBox):
         'activated': (GObject.SignalFlags.RUN_FIRST, None, (int,))
     }
 
-    def __init__(self, show_menu=False, show_loved=False):
+    def __init__(self, show_loved=False):
         """
             Init track widget
-            @param show_menu as bool if menu need to be displayed
+            @param show_loved as bool
         """
         Gtk.ListBox.__init__(self)
         self.connect('destroy', self._on_destroy)
@@ -368,7 +348,6 @@ class TracksWidget(Gtk.ListBox):
                                                     self._update_pos_label)
         self._loved_signal_id = Lp().playlists.connect("playlist-changed",
                                                        self._update_loved_icon)
-        self._show_menu = show_menu
         self._show_loved = show_loved
         self.connect("row-activated", self._on_activate)
         self.get_style_context().add_class('trackswidget')
@@ -385,11 +364,9 @@ class TracksWidget(Gtk.ListBox):
             @param pos as int
             @param show cover as bool
         """
-        track_row = TrackRow(self._show_menu, self._show_loved)
-
+        track_row = TrackRow(self._show_loved)
         track_row.show_indicator(Lp().player.current_track.id == track_id,
                                  utils.is_loved(track_id))
-
         if pos:
             track_row.set_num_label(
                 '''<span foreground="%s"
@@ -415,7 +392,6 @@ class TracksWidget(Gtk.ListBox):
             @param title as str
             @param length as str
             @param pos as int
-            @param show cover as bool
         """
         album_row = AlbumRow(self._show_loved)
         album_row.show_indicator(Lp().player.current_track.id == track_id,
