@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2015 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2016 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -38,7 +38,8 @@ class WebView(Gtk.Stack):
         # Use ressource from ArtistContent
         builder.add_from_resource('/org/gnome/Lollypop/ArtistContent.ui')
         self._view = WebKit2.WebView()
-        self.add_named(builder.get_object('spinner'), 'spinner')
+        self._spinner = builder.get_object('spinner')
+        self.add_named(self._spinner, 'spinner')
         self.set_visible_child_name('spinner')
         self.add_named(self._view, 'view')
         self._view.connect('load-changed', self._on_load_changed)
@@ -89,8 +90,10 @@ class WebView(Gtk.Stack):
         """
         if event == WebKit2.LoadEvent.STARTED:
             self.set_visible_child_name('spinner')
+            self._spinner.start()
         elif event == WebKit2.LoadEvent.FINISHED:
             self.set_visible_child_name('view')
+            self._spinner.stop()
 
     def _on_decide_policy(self, view, decision, decision_type):
         """
