@@ -13,9 +13,10 @@
 from gi.repository import Gtk, Gio, GLib
 
 from lollypop.container import Container
-from lollypop.define import Lp, NextContext, Shuffle
+from lollypop.define import Lp, NextContext, Shuffle, WindowSize
 from lollypop.toolbar import Toolbar
 from lollypop.utils import is_unity
+from lollypop.miniplayer import MiniPlayer
 
 
 class Window(Gtk.ApplicationWindow, Container):
@@ -31,6 +32,8 @@ class Window(Gtk.ApplicationWindow, Container):
         self._app = app
         self._signal1 = None
         self._signal2 = None
+        self._timeout = None
+        self._was_maximized = False
         Gtk.ApplicationWindow.__init__(self,
                                        application=app,
                                        title="Lollypop")
@@ -45,6 +48,11 @@ class Window(Gtk.ApplicationWindow, Container):
         player_action.connect('activate', self._on_player_action)
         app.add_action(player_action)
 
+        self._main_stack = Gtk.Stack()
+        self._main_stack.set_transition_duration(1000)
+        self._main_stack.set_transition_type(Gtk.StackTransitionType.CROSSFADE)
+        self._main_stack.show()
+
         self._setup_content()
         self.setup_window()
         self._setup_media_keys()
@@ -139,18 +147,7 @@ class Window(Gtk.ApplicationWindow, Container):
         """
             Setup window position and size, callbacks
         """
-        size_setting = Lp().settings.get_value('window-size')
-        if isinstance(size_setting[0], int) and\
-           isinstance(size_setting[1], int):
-            self.resize(size_setting[0], size_setting[1])
-        else:
-            self.set_size_request(800, 600)
-        position_setting = Lp().settings.get_value('window-position')
-        if len(position_setting) == 2 and\
-           isinstance(position_setting[0], int) and\
-           isinstance(position_setting[1], int):
-            self.move(position_setting[0], position_setting[1])
-
+        self._setup_pos_size('window')
         if Lp().settings.get_value('window-maximized'):
             self.maximize()
 
@@ -161,9 +158,111 @@ class Window(Gtk.ApplicationWindow, Container):
             self._signal2 = self.connect("configure-event",
                                          self._on_configure_event)
 
+    def responsive_design(self):
+        """
+            Handle responsive design
+        """
+        size = self.get_size()
+        self._toolbar.set_content_width(size[0])
+        view = self._stack.get_visible_child()
+        if view:
+            view.update_responsive_design()
+        if view and hasattr(view, 'show_context'):
+            view.show_context(size[0] > WindowSize.MEDIUM)
+        if Lp().player.current_track.id is not None:
+            self._show_miniplayer(size[0] < WindowSize.MEDIUM)
+            self._show_subtoolbar(size[0] < WindowSize.MONSTER and
+                                  size[0] > WindowSize.MEDIUM)
+
+    def set_mini(self):
+        """
+            Set mini player on/off
+        """
+        if Lp().player.current_track.id is None:
+            return
+        was_maximized = self.is_maximized()
+        if self._main_stack.get_visible_child_name() == 'main':
+            if self.is_maximized():
+                self.unmaximize()
+                GLib.timeout_add(100, self._setup_pos_size, 'mini')
+            else:
+                self._setup_pos_size('mini')
+        elif self._was_maximized:
+            self.maximize()
+        else:
+            self._setup_pos_size('window')
+        self._was_maximized = was_maximized
+
 ############
 # Private  #
 ############
+    def _show_subtoolbar(self, show):
+        """
+            Show/hide subtoolbar
+            @param show as bool
+        """
+        is_visible = self._subtoolbar.is_visible()
+        if show and not is_visible:
+            mini = MiniPlayer()
+            mini.show()
+            self._subtoolbar.add(mini)
+            self._subtoolbar.show()
+        elif not show and is_visible:
+            children = self._subtoolbar.get_children()
+            if children:
+                children[0].destroy()
+            self._subtoolbar.hide()
+
+    def _show_miniplayer(self, show):
+        """
+            Show/hide miniplayer
+            @param show as bool
+        """
+        mini = self._main_stack.get_child_by_name('mini')
+        if show:
+            if mini is not None:
+                if self._timeout is not None:
+                    GLib.source_remove(self._timeout)
+            else:
+                mini = MiniPlayer()
+                self._main_stack.add_named(mini, 'mini')
+            self._timeout = None
+            mini.show()
+            self._main_stack.set_visible_child_name('mini')
+            self._toolbar.set_show_close_button(False)
+        elif mini is not None and not show and self._timeout is None:
+            self._main_stack.set_visible_child_name('main')
+            self._toolbar.set_show_close_button(True)
+            self._timeout = GLib.timeout_add(1000, mini.destroy)
+
+    def _setup_pos_size(self, name):
+        """
+            Set window pos and size based on name
+            @param name as str
+        """
+        size_setting = Lp().settings.get_value('%s-size' % name)
+        if len(size_setting) == 2 and\
+           isinstance(size_setting[0], int) and\
+           isinstance(size_setting[1], int):
+            self.resize(size_setting[0], size_setting[1])
+        if name == 'window':
+            self._setup_pos(name)
+        else:
+            # We need position to happen after resize as previous
+            # may be refused by window manager => mini player as bottom
+            GLib.idle_add(self._setup_pos, name)
+
+    def _setup_pos(self, name):
+        """
+            Set window position
+            @param name as str
+        """
+        position_setting = Lp().settings.get_value('%s-position' % name)
+        if len(position_setting) == 2 and\
+           isinstance(position_setting[0], int) and\
+           isinstance(position_setting[1], int):
+            self.move(position_setting[0], position_setting[1])
+
     def _setup_media_keys(self):
         """
             Setup media player keys
@@ -222,19 +321,22 @@ class Window(Gtk.ApplicationWindow, Container):
             Setup window content
         """
         self.set_icon_name('lollypop')
+        vgrid = Gtk.Grid()
+        vgrid.set_orientation(Gtk.Orientation.VERTICAL)
+        vgrid.show()
         self._toolbar = Toolbar(self.get_application())
         self._toolbar.show()
+        self._subtoolbar = Gtk.Grid()
         if Lp().settings.get_value('disable-csd') or is_unity():
-            vgrid = Gtk.Grid()
-            vgrid.set_orientation(Gtk.Orientation.VERTICAL)
             vgrid.add(self._toolbar)
-            vgrid.add(self.main_widget())
-            vgrid.show()
-            self.add(vgrid)
         else:
             self.set_titlebar(self._toolbar)
             self._toolbar.set_show_close_button(True)
-            self.add(self.main_widget())
+        vgrid.add(self._main_stack)
+        vgrid.add(self._subtoolbar)
+        self.add(vgrid)
+        self._main_stack.add_named(self.main_widget(), 'main')
+        self._main_stack.set_visible_child_name('main')
 
     def _on_configure_event(self, widget, event):
         """
@@ -242,13 +344,13 @@ class Window(Gtk.ApplicationWindow, Container):
             @param: widget as Gtk.Window
             @param: event as Gdk.Event
         """
-        self._toolbar.set_content_width()
         if self._timeout_configure:
             GLib.source_remove(self._timeout_configure)
             self._timeout_configure = None
+        self.responsive_design()
         if not self.is_maximized():
             self._timeout_configure = GLib.timeout_add(
-                                                   500,
+                                                   1000,
                                                    self._save_size_position,
                                                    widget)
 
@@ -259,12 +361,17 @@ class Window(Gtk.ApplicationWindow, Container):
         """
         self._timeout_configure = None
         size = widget.get_size()
-        Lp().settings.set_value('window-size',
+        if size[0] > WindowSize.MEDIUM:
+            name = 'window'
+        else:
+            name = 'mini'
+        Lp().settings.set_value('%s-size' % name,
                                 GLib.Variant('ai', [size[0], size[1]]))
 
         position = widget.get_position()
-        Lp().settings.set_value('window-position',
-                                GLib.Variant('ai', [position[0], position[1]]))
+        Lp().settings.set_value('%s-position' % name,
+                                GLib.Variant('ai',
+                                             [position[0], position[1]]))
 
     def _on_window_state_event(self, widget, event):
         """
@@ -279,6 +386,9 @@ class Window(Gtk.ApplicationWindow, Container):
             Save paned widget width
             @param widget as unused, data as unused
         """
+        if self._was_maximized and\
+           self._main_stack.get_visible_child_name() == 'mini':
+            Lp().settings.set_boolean('window-maximized', True)
         Lp().settings.set_value('paned-mainlist-width',
                                 GLib.Variant('i',
                                              self._paned_main_list.
